Filterer
========

.. currentmodule:: pykeen.sampling.filtering

.. autoclass:: Filterer
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Filterer.contains
      ~Filterer.forward

   .. rubric:: Methods Documentation

   .. automethod:: contains
   .. automethod:: forward
